# Duplocloud Py Client  

![Tests](https://github.com/duplocloud/py-client/actions/workflows/test.yml/badge.svg) | ![PyPI - Version](https://img.shields.io/pypi/v/duplocloud-client)


A package to spawn service clients for working with Duplocloud. 

## Installation  

From PyPi:
```
pip install duplocloud-client
```

From source:
```
pip install .
```

